﻿using Infragistics.Controls.Grids;
using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Interactivity;

namespace MVVMCurrentSelectedRecordCase
{
    class SelectedRecordBehavior : Behavior<XamGrid>
    {
        private XamGrid Grid
        {
            get
            {
                return AssociatedObject as XamGrid;
            }
        }

        public INotifyCollectionChanged SelectedItems
        {
            get { return (INotifyCollectionChanged)GetValue(SelectedItemsProperty); }
            set { SetValue(SelectedItemsProperty, value); }
        }

        public static readonly DependencyProperty SelectedItemsProperty = DependencyProperty.Register(
            "SelectedItems",
            typeof(INotifyCollectionChanged),
            typeof(SelectedRecordBehavior),
            null);

        protected override void OnAttached()
        {
            base.OnAttached();                     
            Grid.SelectedRowsCollectionChanged += Grid_SelectedRowsCollectionChanged;
        }

        void Grid_SelectedRowsCollectionChanged(object sender, SelectionCollectionChangedEventArgs<SelectedRowsCollection> e)
        {
            UnsubscribeFromEvents();
            TransferSourceToTarget(Grid.SelectionSettings.SelectedRows, this.SelectedItems as IList);
            SubscribeToEvents();
        }

        private void SubscribeToEvents()
        {
            Grid.SelectedRowsCollectionChanged+=Grid_SelectedRowsCollectionChanged;
        }

        private void UnsubscribeFromEvents()
        {
            Grid.SelectedRowsCollectionChanged-=Grid_SelectedRowsCollectionChanged;
        }

        public static void TransferSourceToTarget(IList source, IList target)
        {
            if (source == null || target == null)
            {
                return;
            }
            target.Clear();
            foreach (Row r in source)
            {
                if (r.RowType == RowType.DataRow && r.ParentRow == null)
                {
                    target.Add(r.Data);
                }
            }
        }
    }
}
